@@ -4,12 +4,12 @@
 file_catalog
 ============
 
-With **file_catalog**, you can set up a mapping of file names to their paths.
-An application can then use the catalog to retrieve the paths based on
-the file name. By keeping different catalogs with the same file names but
-different paths, different runs of the application can use each of the
-different catalogs as appropriate. For example, one catalog could be used
-for testing purposes and another for normal production.
+With **file_catalog**, you can set up a mapping of file names to their
+paths. An application can then use the catalog to retrieve the paths
+based on the file name. By keeping different catalogs with the same file
+names but different paths, different runs of the application can use
+each of the different catalogs as appropriate. For example, one catalog
+could be used for testing purposes and another for normal production.
 
 :Example: instantiate production and test catalogs for one file
 
@@ -18,14 +18,13 @@ for testing purposes and another for normal production.
 >>> print(prod_cat.get_path('file1'))
 /prod_files/file1.csv
 
->>> test_cat = FileCatalog({'file1': Path('/test_files/test_file1.csv')})
+>>> test_cat = FileCatalog(
+...     {'file1': Path('/test_files/test_file1.csv')})
 >>> print(test_cat.get_path('file1'))
 /test_files/test_file1.csv
 
-Note that you can use any file name you want as long as it is a string - it
-does not have to be any part of the path
 
-:Example: instantiate a catalog for two files with:
+:Example: instantiate a catalog for two files:
 
 >>> a_cat = FileCatalog({'sales': Path('/home/T/files/file1.csv'),
 ...                      'inventory': Path('/home/T/files/file2.csv')})
@@ -43,8 +42,8 @@ FileCatalog({'sales': Path('/home/T/files/file1.csv'),
 
 The file_catalog module contains:
 
-    1) FileCatalog class with add_paths, del_paths,  get_path, save_catalog,
-       and load_catalog methods
+    1) FileCatalog class with add_paths, del_paths,  get_path,
+       save_catalog, and load_catalog methods
     2) FileSpec, FileSpecs type aliases that you can use for type hints
     3) Error exception classes:
 
@@ -62,37 +61,37 @@ FileSpecs = Dict[str, Path]
 
 
 class FileCatalogError(Exception):
-    """Base class for exception in this module."""
-    pass
-
-
-class FileSpecIncorrect(FileCatalogError):
-    """FileCatalog exception for an incorrect file_specs specification."""
-    pass
-
-
-class IllegalAddAttempt(FileCatalogError):
-    """FileCatalog exception attempted add of existing but different path."""
-    pass
-
-
-class IllegalDelAttempt(FileCatalogError):
-    """FileCatalog exception attempted del of existing but different path."""
+    """Base class for exceptions in this module."""
     pass
 
 
 class FileNameNotFound(FileCatalogError):
-    """FileNameNotFound exception when the file name is not in the catalog."""
+    """FileNameNotFound when the file name is not in the catalog."""
+    pass
+
+
+class FileSpecIncorrect(FileCatalogError):
+    """FileCatalog incorrect file_specs specification."""
+    pass
+
+
+class IllegalAddAttempt(FileCatalogError):
+    """FileCatalog attempted add of existing but different path."""
+    pass
+
+
+class IllegalDelAttempt(FileCatalogError):
+    """FileCatalog attempted del of existing but different path."""
     pass
 
 
 class FileCatalog:
     """Provides a mapping of file names to paths.
 
-    This is useful for cases where an application is to be used in various
-    environments with files that are in different places. Another use is where
-    one set of files is used for normal processing and another set is used for
-    testing purposes.
+    This is useful for cases where an application is to be used in
+    various environments with files that are in different places.
+    Another use is where one set of files is used for normal processing
+    and another set is used for testing purposes.
     """
 
     def __init__(self,
@@ -101,15 +100,17 @@ class FileCatalog:
         """Store the input file specs to a data frame.
 
         Args:
-            file_specs: A dictionary of one or more entries. The key is the
-                          file name and the value is the path. The file name
-                          must be a sting and the path must be a pathlib Path.
+            file_specs: A dictionary of one or more entries. The key is
+                          the file name and the value is the path. The
+                          file name must be a sting and the path must be
+                          a pathlib Path.
 
         :Example: instantiate a catalog with two files
 
         >>> from scottbrian_utils.file_catalog import FileCatalog
-        >>> a_catalog = FileCatalog({'file_1': Path('/run/media/file1.csv'),
-        ...                          'file_2': Path('/run/media/file2.pdf')})
+        >>> a_catalog = FileCatalog(
+        ...     {'file_1': Path('/run/media/file1.csv'),
+        ...      'file_2': Path('/run/media/file2.pdf')})
         >>> print(a_catalog.get_path('file_2'))
         /run/media/file2.pdf
 
@@ -127,9 +128,10 @@ class FileCatalog:
         :Example: instantiate a catalog with three files
 
         >>> from scottbrian_utils.file_catalog import FileCatalog
-        >>> a_catalog = FileCatalog({'file1': Path('/run/media/file1.csv'),
-        ...                          'file2': Path('/run/media/file2.pdf'),
-        ...                          'file5': Path('/run/media/file5.csv')})
+        >>> a_catalog = FileCatalog(
+        ...     {'file1': Path('/run/media/file1.csv'),
+        ...      'file2': Path('/run/media/file2.pdf'),
+        ...      'file5': Path('/run/media/file5.csv')})
         >>> len(a_catalog)
         3
 
@@ -145,9 +147,10 @@ class FileCatalog:
         :Example: instantiate a catalog with three files and print it
 
         >>> from scottbrian_utils.file_catalog import FileCatalog
-        >>> a_catalog = FileCatalog({'file1': Path('/run/media/file1.csv'),
-        ...                          'file2': Path('/run/media/file2.pdf'),
-        ...                          'file5': Path('/run/media/file5.csv')})
+        >>> a_catalog = FileCatalog(
+        ...     {'file1': Path('/run/media/file1.csv'),
+        ...      'file2': Path('/run/media/file2.pdf'),
+        ...      'file5': Path('/run/media/file5.csv')})
         >>> print(a_catalog)
         FileCatalog({'file1': Path('/run/media/file1.csv'),
                      'file2': Path('/run/media/file2.pdf'),
@@ -169,7 +172,8 @@ class FileCatalog:
                     or (i < num_start_entries) \
                     or (i == num_entries-1):
                 parms = parms + indent_spaces + "'" + file_name \
-                         + "': " + "Path(" + "'" + str(path) + "'),\n"
+                         + "': " + "Path(" + "'" + str(path.as_posix()) \
+                         + "'),\n"
 
             # put in the ellipse
             if num_entries > 4:
@@ -196,11 +200,13 @@ class FileCatalog:
         Raises:
             FileNameNotFound: The input file name is not in the catalog
 
-        :Example: instantiate a catalog with two files and get their paths
+        :Example: instantiate a catalog with two files and get their
+                  paths
 
         >>> from scottbrian_utils.file_catalog import FileCatalog
-        >>> a_catalog = FileCatalog({'file1': Path('/run/media/file1.csv'),
-        ...                          'file2': Path('/run/media/file2.pdf')})
+        >>> a_catalog = FileCatalog(
+        ...    {'file1': Path('/run/media/file1.csv'),
+        ...     'file2': Path('/run/media/file2.pdf')})
         >>> path1 = a_catalog.get_path('file1')
         >>> print(path1)
         /run/media/file1.csv
@@ -214,30 +220,31 @@ class FileCatalog:
             return self.catalog[file_name]
         except KeyError:
             raise FileNameNotFound('Catalog does not have an entry for'
-                                   'file name:', file_name)
+                                   f'file name: {file_name}')
 
     def add_paths(self, file_specs: FileSpecs) -> None:
         """Add one or more paths to the catalog.
 
         Args:
-            file_specs: A dictionary of one or more entries. The key is the
-                          file name and the value is the path. The file name
-                          must be a sting and the path must be a pathlib Path.
+            file_specs: A dictionary of one or more entries. The key is
+                          the file name and the value is the path. The
+                          file name must be a sting and the path must be
+                          a pathlib Path.
 
         Raises:
             FileSpecIncorrect: The input path is not a string
             IllegalAddAttempt: Entry already exists with different path
 
-        The entries to be added are specified in the file_specs argument.
-        For each file_spec, the specified file name is used to determine
-        whether the entry already exists in the catalog. If the entry
-        already exists, the specified path is compared against the
-        found entry. If they do not match, an IllegalAddAttempt exception is
-        raised and no entries for the add_paths request will be added.
-        Otherwise, if the path matches, there is no need to add it again
-        so processing continues with the next file_spec. If no errors are
-        detected for any of the file_specs, any file names that do not yet
-        exist in the catalog are added.
+        The entries to be added are specified in the file_specs
+        argument. For each file_spec, the specified file name is used to
+        determine whether the entry already exists in the catalog. If
+        the entry already exists, the specified path is compared against
+        the found entry. If they do not match, an IllegalAddAttempt
+        exception is raised and no entries for the add_paths request
+        will be added. Otherwise, if the path matches, there is no need
+        to add it again so processing continues with the next file_spec.
+        If no errors are detected for any of the file_specs, any file
+        names that do not yet exist in the catalog are added.
 
         :Example: add some paths to the catalog
 
@@ -263,7 +270,7 @@ class FileCatalog:
                 raise FileSpecIncorrect('Specified file name', file_name,
                                         'is not a string')
             if not isinstance(path, Path):
-                raise FileSpecIncorrect('Specified path', path, 'not Path')
+                raise FileSpecIncorrect(f'Specified path {path} is not a Path')
             if ((file_name in self.catalog) and
                     (self.catalog[file_name] != path)):
                 raise IllegalAddAttempt(
@@ -277,23 +284,26 @@ class FileCatalog:
         """Delete one or more paths from the catalog.
 
         Args:
-            file_specs: A dictionary of one or more entries. The key is the
-                          file name and the value is the path. The file name
-                          must be a sting and the path must be a pathlib Path.
+            file_specs: A dictionary of one or more entries. The key is
+                          the file name and the value is the path. The
+                          file name must be a sting and the path must be
+                          a pathlib Path.
 
         Raises:
             FileSpecIncorrect: The input path is not a string
-            IllegalDelAttempt: Attempt to delete entry with different path
+            IllegalDelAttempt: Attempt to delete entry with different
+                path
 
-        The entries to be deleted are specified in the file_specs argument.
-        For each file_spec, the specified file name is used to find the
-        entry in the catalog. If not found, processing continues with the
-        next file_spec. Otherwise, if the entry is found, the specified
-        path from the file_spec is compared against the path in the
-        found entry. If not equal, an IllegalDelAttempt exception is raised
-        and no entries for the del_paths request will be deleted. Otherwise,
-        if the path matches, the entry will be deleted provided no
-        errors are detected for any of the preceeding or remaining file_specs.
+        The entries to be deleted are specified in the file_specs
+        argument. For each file_spec, the specified file name is used to
+        find the entry in the catalog. If not found, processing
+        continues with the next file_spec. Otherwise, if the entry is
+        found, the specified path from the file_spec is compared against
+        the path in the found entry. If not equal, an IllegalDelAttempt
+        exception is raised and no entries for the del_paths request
+        will be deleted. Otherwise, if the path matches, the entry will
+        be deleted provided no errors are detected for any of the
+        preceeding or remaining file_specs.
 
         :Example: add and then delete paths from the catalog
 
@@ -361,7 +371,8 @@ class FileCatalog:
         """Load catalog from a csv file.
 
         Args:
-            saved_cat_path: The path from where the catalog is to be loaded
+            saved_cat_path: The path from where the catalog is to be
+                              loaded
 
         Returns:
             A FileCatalog instance
