@@ -1,15 +1,30 @@
 """test_time_hdr.py module."""
 
-from datetime import datetime, timedelta
-import pytest
+########################################################################
+# Standard Library
+########################################################################
+from datetime import datetime, timedelta, timezone
+import logging
+import re
 import sys
 
 from typing import Any, Callable, cast, Tuple, Union
 from typing_extensions import Final
 
+########################################################################
+# Third Party
+########################################################################
+import pytest
+
+########################################################################
+# Local
+########################################################################
 from scottbrian_utils.time_hdr import StartStopHeader as StartStopHeader
 from scottbrian_utils.time_hdr import time_box as time_box
 from scottbrian_utils.time_hdr import DT_Format as DT_Format
+from scottbrian_utils.time_hdr import get_datetime_match_string
+
+logger = logging.getLogger(__name__)
 
 
 class ErrorTstTimeHdr(Exception):
@@ -50,6 +65,183 @@ def dt_format_arg(request: Any) -> str:
     return cast(str, request.param)
 
 
+dt_format_char_arg_list = ['',
+                           '%a',
+                           '%A',
+                           '%w',
+                           '%d',
+                           '%b',
+                           '%B',
+                           '%m',
+                           '%y',
+                           '%Y',
+                           '%H',
+                           '%I',
+                           '%p',
+                           '%M',
+                           '%S',
+                           '%f',
+                           '%z',
+                           '%Z'
+                           '%j',
+                           '%U',
+                           '%W',
+                           '%c',
+                           '%x',
+                           '%X',
+                           '%%',
+                           '%G',
+                           '%u',
+                           '%V']
+
+
+@pytest.fixture(params=dt_format_char_arg_list)  # type: ignore
+def dt_format_char_arg(request: Any) -> str:
+    """Using different time formats.
+
+    Args:
+        request: special fixture that returns the fixture params
+
+    Returns:
+        The params values are returned one at a time
+    """
+    return cast(str, request.param)
+
+
+dt_datetime_arg_list = [datetime(1999,  1,  1,  0,  0,  0,  0,
+                                 tzinfo=timezone.utc
+                                 ),
+                        datetime(2000,  2,  2,  1,  1,  1,  1,
+                                 tzinfo=timezone.utc
+                                 ),
+                        datetime(2001,  3,  9,  9,  9,  9,  9,
+                                 tzinfo=timezone(timedelta(hours=-23,
+                                                           minutes=-59))
+                                 ),
+                        datetime(2002,  4, 10, 10, 10, 10, 10,
+                                 tzinfo=timezone(timedelta(hours=-23))
+                                 ),
+                        datetime(2009,  5, 11, 11, 11, 11, 11,
+                                 tzinfo=timezone(timedelta(hours=-5))
+                                 ),
+                        datetime(2010,  6, 19, 19, 19, 19, 19,
+                                 tzinfo=timezone(timedelta(hours=-5)),
+                                 ),
+                        datetime(2011,  7, 20, 20, 20, 20, 20,
+                                 tzinfo=timezone(timedelta(hours=0))
+                                 ),
+                        datetime(2019,  9, 21, 21, 21, 21, 21,
+                                 tzinfo=timezone(timedelta(minutes=1))
+                                 ),
+                        datetime(2020, 10, 29, 22, 29, 29, 29,
+                                 tzinfo=timezone(timedelta(hours=1))
+                                 ),
+                        datetime(2021, 11, 30, 23, 30, 30, 30,
+                                 tzinfo=timezone(timedelta(hours=23,
+                                                           minutes=59))
+                                 ),
+                        datetime(2022, 12, 31, 23, 59, 59, 999999,
+                                 tzinfo=timezone(timedelta(hours=23,
+                                                           minutes=59)),
+                                 )]
+
+
+@pytest.fixture(params=dt_datetime_arg_list)  # type: ignore
+def dt_datetime_arg(request: Any) -> datetime:
+    """Using different time formats.
+
+    Args:
+        request: special fixture that returns the fixture params
+
+    Returns:
+        The params values are returned one at a time
+    """
+    return cast(datetime, request.param)
+
+
+dt_datetime_month_arg_list = [1, 5, 9, 10, 11, 12]
+
+
+@pytest.fixture(params=dt_datetime_month_arg_list)  # type: ignore
+def dt_datetime_month_arg(request: Any) -> int:
+    """Using different time formats.
+
+    Args:
+        request: special fixture that returns the fixture params
+
+    Returns:
+        The params values are returned one at a time
+    """
+    return cast(int, request.param)
+
+
+dt_datetime_day_arg_list = [1, 2, 9, 10, 11, 19, 20, 21, 29, 30, 31]
+
+
+@pytest.fixture(params=dt_datetime_day_arg_list)  # type: ignore
+def dt_datetime_day_arg(request: Any) -> int:
+    """Using different time formats.
+
+    Args:
+        request: special fixture that returns the fixture params
+
+    Returns:
+        The params values are returned one at a time
+    """
+    return cast(int, request.param)
+
+
+dt_format_date_arg_list = ['',
+                           'weekday: %w, %m/%y',
+                           '(weekday): %w, %m/%Y',
+                           '%m/%d/%y',
+                           '%m/%d/%Y',
+                           '%a %b %Y',
+                           '%a %B %Y',
+                           '%A %b %Y',
+                           '%A %B %Y',
+                           '%d %b %Y'
+                           ]
+
+dt_format_time_arg_list = ['',
+                           'hour: %H',
+                           '[hour/min]: %H:%M',
+                           '%H:%M',
+                           '%H:%M:%S',
+                           '%I:%M %p',
+                           '%I:%M:%S %p',
+                           '%H:%M:%S.%f',
+                           '%H:%M:%S.%f%z',
+                           '%H:%M:%S.%f %Z'
+                           ]
+
+
+@pytest.fixture(params=dt_format_date_arg_list)  # type: ignore
+def dt_format_date_arg(request: Any) -> str:
+    """Using different time formats.
+
+    Args:
+        request: special fixture that returns the fixture params
+
+    Returns:
+        The params values are returned one at a time
+    """
+    return cast(str, request.param)
+
+
+@pytest.fixture(params=dt_format_time_arg_list)  # type: ignore
+def dt_format_time_arg(request: Any) -> str:
+    """Using different time formats.
+
+    Args:
+        request: special fixture that returns the fixture params
+
+    Returns:
+        The params values are returned one at a time
+    """
+    return cast(str, request.param)
+
+
 style_num_list = [1, 2, 3]
 
 
@@ -135,6 +327,175 @@ def enabled_arg(request: Any) -> str:
     return cast(str, request.param)
 
 
+class TestGetMatchStr:
+    """Test formatted re strings."""
+
+    ####################################################################
+    # test_get_datetime_match_string_mid
+    ####################################################################
+    def test_get_datetime_char_match(self,
+                                     dt_format_char_arg: str,
+                                     dt_datetime_arg: datetime
+                                     ) -> None:
+        """Test the datetime match string for one char.
+
+        Args:
+            dt_format_char_arg: pytest fixture for char arg
+            dt_datetime_arg: pytest fixture for datetime arg
+
+        """
+        print(f'\n{dt_format_char_arg=}')
+
+        old_datetime = dt_datetime_arg.strftime(dt_format_char_arg)
+
+        new_datetime = datetime.now(
+            timezone(timedelta(hours=1))).strftime(dt_format_char_arg)
+
+        formatted_old_dt = (f"{old_datetime} was a good time.")
+        print(f'{formatted_old_dt=}')
+
+        formatted_new_dt = (f"{new_datetime} was a good time.")
+        print(f'{formatted_new_dt=}')
+
+        match_str = get_datetime_match_string(dt_format_char_arg)
+        print(f'{match_str=}')
+
+        adjusted_old_dt = re.sub(match_str, new_datetime, formatted_old_dt)
+        print(f'{adjusted_old_dt=}')
+
+        assert formatted_new_dt == adjusted_old_dt
+
+    ####################################################################
+    # test_get_datetime_match_string_mid
+    ####################################################################
+    def test_get_datetime_match_string_start(self,
+                                             dt_format_date_arg: str,
+                                             dt_format_time_arg: str,
+                                             dt_datetime_arg: datetime
+                                             ) -> None:
+        """Test the datetime match string at start of text.
+
+        Args:
+            dt_format_date_arg: pytest fixture for date arg
+            dt_format_time_arg: pytest fixture for time arg
+            dt_datetime_arg: pytest fixture for datetime arg
+
+        """
+        if dt_format_date_arg == '':
+            dt_format = f'{dt_format_time_arg}'
+        else:
+            dt_format = f'{dt_format_date_arg} {dt_format_time_arg}'
+
+        print(f'\n{dt_format=}')
+
+        old_datetime = dt_datetime_arg.strftime(dt_format)
+
+        new_datetime = datetime.now(
+            timezone(timedelta(hours=1))).strftime(dt_format)
+
+        formatted_old_dt = (f"{old_datetime} was a good time.")
+        print(f'{formatted_old_dt=}')
+
+        formatted_new_dt = (f"{new_datetime} was a good time.")
+        print(f'{formatted_new_dt=}')
+
+        match_str = get_datetime_match_string(dt_format)
+        print(f'{match_str=}')
+
+        adjusted_old_dt = re.sub(match_str, new_datetime, formatted_old_dt)
+        print(f'{adjusted_old_dt=}')
+
+        assert formatted_new_dt == adjusted_old_dt
+
+    ####################################################################
+    # test_get_datetime_match_string_mid
+    ####################################################################
+    def test_get_datetime_match_string_mid(self,
+                                           dt_format_date_arg: str,
+                                           dt_format_time_arg: str,
+                                           dt_datetime_arg: datetime
+                                           ) -> None:
+        """Test the datetime match string.
+
+        Args:
+            dt_format_date_arg: pytest fixture for date arg
+            dt_format_time_arg: pytest fixture for time arg
+            dt_datetime_arg: pytest fixture for datetime arg
+
+        """
+        if dt_format_date_arg == '':
+            dt_format = f'{dt_format_time_arg}'
+        else:
+            dt_format = f'{dt_format_date_arg} {dt_format_time_arg}'
+
+        print(f'\n{dt_format=}')
+
+        old_datetime = dt_datetime_arg.strftime(dt_format)
+
+        new_datetime = datetime.now(
+            timezone(timedelta(hours=1))).strftime(dt_format)
+
+        formatted_old_dt = (f"Here it is: {old_datetime} with "
+                            f"the formatting we want.")
+        print(f'{formatted_old_dt=}')
+
+        formatted_new_dt = (f"Here it is: {new_datetime} with "
+                            f"the formatting we want.")
+        print(f'{formatted_new_dt=}')
+
+        match_str = get_datetime_match_string(dt_format)
+        print(f'{match_str=}')
+
+        adjusted_old_dt = re.sub(match_str, new_datetime, formatted_old_dt)
+        print(f'{adjusted_old_dt=}')
+
+        assert formatted_new_dt == adjusted_old_dt
+
+    ####################################################################
+    # test_get_datetime_match_string_end
+    ####################################################################
+    def test_get_datetime_match_string_end(self,
+                                           dt_format_date_arg: str,
+                                           dt_format_time_arg: str,
+                                           dt_datetime_arg: datetime
+                                           ) -> None:
+        """Test the datetime match string at end of test.
+
+        Args:
+            dt_format_date_arg: pytest fixture for date arg
+            dt_format_time_arg: pytest fixture for time arg
+            dt_datetime_arg: pytest fixture for datetime arg
+
+        """
+        if dt_format_date_arg == '':
+            dt_format = f'{dt_format_time_arg}'
+        else:
+            dt_format = f'{dt_format_date_arg} {dt_format_time_arg}'
+
+        print(f'\n{dt_format=}')
+
+        old_datetime = dt_datetime_arg.strftime(dt_format)
+
+        new_datetime = datetime.now(
+            timezone(timedelta(hours=1))).strftime(dt_format)
+
+        formatted_old_dt = (f"Time is on your side:"
+                            f" {old_datetime}")
+        print(f'{formatted_old_dt=}')
+
+        formatted_new_dt = (f"Time is on your side:"
+                            f" {new_datetime}")
+        print(f'{formatted_new_dt=}')
+
+        match_str = get_datetime_match_string(dt_format)
+        print(f'{match_str=}')
+
+        adjusted_old_dt = re.sub(match_str, new_datetime, formatted_old_dt)
+        print(f'{adjusted_old_dt=}')
+
+        assert formatted_new_dt == adjusted_old_dt
+
+
 class TestStartStopHeader:
     """TestStartStopHeader class."""
 
@@ -395,7 +756,7 @@ class TestTimeBox:
             if file != 'None':
                 expected_file = file
 
-        # Note: we can specify flush but we can not verify whether it works
+        # Note: we can specify flush, but we can't verify that it works
         expected_flush = False
         if flush != '0':
             route_num = route_num | TestTimeBox.FLUSH1
@@ -428,10 +789,11 @@ class TestTimeBox:
         Args:
             expected_func_msg: message issued by wrapped function
             actual: the message captured by capsys
-            expected_dt_format: dt_format to use to build expected message
+            expected_dt_format: dt_format to use to build expected
+                                  message
             expected_end: end arg to use to build expected message
-            expected_enabled_tf: expected enabled arg to use to build expected
-                                   message
+            expected_enabled_tf: expected enabled arg to use to build
+                                   expected message
 
         Returns:
             the expected message that is built based on the input args
@@ -442,35 +804,40 @@ class TestTimeBox:
             else:
                 return expected_func_msg + '\n'
 
-        start_dt = datetime.now()
-        end_dt = datetime.now() + timedelta(microseconds=42)
-        formatted_delta = str(end_dt - start_dt)
-        formatted_delta_len = len(formatted_delta)
+        match_fmt_string = get_datetime_match_string(expected_dt_format)
 
-        formatted_dt = start_dt.strftime(expected_dt_format)
-        formatted_dt_len = len(formatted_dt)
+        # get start time
+        match_re = re.compile('Starting func on ' + match_fmt_string)
+        match_obj = match_re.search(actual)
+        assert match_obj
+        start_time = match_obj.group()
 
-        start_time_marks = '#' * formatted_dt_len
+        # get end time
+        match_re = re.compile('Ending func on ' + match_fmt_string)
+        match_obj = match_re.search(actual)
+        assert match_obj
+        end_time = match_obj.group()
 
-        start_time_len = len(start_time_marks)
-        end_time_marks = '%' * formatted_dt_len
-        end_time_len = len(end_time_marks)
-        elapsed_time_marks = '$' * formatted_delta_len
-        elapsed_time_len = len(elapsed_time_marks)
-        # build expected0
-        msg0 = '* Starting func on ' + start_time_marks
+        # get elapsed time
+        match_re = re.compile('Elapsed time: '
+                              '[0-9]:[0-9]{2}:[0-9]{2}( |.[0-9]{1,6} )')
+        match_obj = match_re.search(actual)
+        assert match_obj
+        elapsed_time = match_obj.group()[0:-1]
+
+        msg0 = '* ' + start_time
 
         flower_len = len(msg0) + len(' *')
         flowers = '*' * flower_len
 
         msg0 += ' ' * (flower_len - len(msg0) - 1) + '*'
 
-        expected0 = '\n' + flowers + expected_end + msg0 + expected_end \
-            + flowers + expected_end
+        expected0 = ('\n' + flowers + expected_end + msg0 + expected_end
+                     + flowers + expected_end)
 
         # build expected1
-        msg1 = '* Ending func on ' + end_time_marks
-        msg2 = '* Elapsed time: ' + elapsed_time_marks
+        msg1 = '* ' + end_time
+        msg2 = '* ' + elapsed_time
 
         expected1 = TestStartStopHeader.get_flower_box(msg1, msg2,
                                                        expected_end)
@@ -480,31 +847,18 @@ class TestTimeBox:
         else:
             expected = expected0 + expected_func_msg + '\n' + expected1
 
-        # find positions of the start, end, and elapsed times
-        start_time_index = expected.index(start_time_marks)
-        end_time_index = expected.index(end_time_marks)
-        elapsed_time_index = expected.index(elapsed_time_marks)
-
-        modified_expected = expected[0:start_time_index] \
-            + actual[start_time_index:start_time_index+start_time_len] \
-            + expected[start_time_index+start_time_len:end_time_index] \
-            + actual[end_time_index:end_time_index+end_time_len] \
-            + expected[end_time_index+end_time_len:elapsed_time_index] \
-            + actual[elapsed_time_index:elapsed_time_index+elapsed_time_len] \
-            + expected[elapsed_time_index+elapsed_time_len:]
-
-        return modified_expected
+        return expected
 
     """
-    The following section tests each combination of arguments to the time_box
-    decorator for three styles of decoration (using pie, calling the
-    with the function as the first parameter, and calling the decorator with
-    the function specified after the call. This test is especially useful to
-    ensure that the type hints are working correctly, and that all
-    combinations are accepted by python.
+    The following section tests each combination of arguments to the
+    time_box decorator for three styles of decoration (using pie,
+    calling with the function as the first parameter, and calling the
+    decorator with the function specified after the call. This test is
+    especially useful to ensure that the type hints are working
+    correctly, and that all combinations are accepted by python.
 
-    The following keywords with various values and in all combinations are
-    tested:
+    The following keywords with various values and in all combinations
+    are tested:
         dt_format - several different datetime formats - see format_list
         end - either '\n' for single space, and '\n\n' for double space
         file - either sys.stdout or sys.stderr
